/**
 * SPDX-FileCopyrightText: Copyright 2023 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: BSD-3-Clause
 */
#include <embedder_texture/embedder_texture_plugin.h>
#include <flutter/method-channel.h>
#include <flutter/platform-data.h>
#include <flutter/platform-events.h>
#include <flutter/platform-methods.h>

EmbedderTexturePlugin::EmbedderTexturePlugin()
{
    PlatformEvents::SubscribeOrientationChanged([this](DisplayRotation orientation) {
        if (this->m_isEnableOrientationChanged) {
            EventChannel("embedder_texture_orientation", MethodCodecType::Standard)
                .SendEvent(static_cast<int>(orientation));
        }
    });
}

void EmbedderTexturePlugin::RegisterWithRegistrar(PluginRegistrar &registrar)
{
    TextureRegistrar *plugin = registrar.GetRegisterTexture();

    m_camera = new Camera(plugin);

    registrar.RegisterMethodChannel("embedder_texture",
                                    MethodCodecType::Standard,
                                    [this](const MethodCall &call) { this->onMethodCall(call); });

    registrar.RegisterEventChannel(
        "embedder_texture_orientation",
        MethodCodecType::Standard,
        [this](const Encodable &) {
            this->m_isEnableOrientationChanged = true;
            return EventResponse();
        },
        [this](const Encodable &) {
            this->m_isEnableOrientationChanged = false;
            return EventResponse();
        });

}

void EmbedderTexturePlugin::onMethodCall(const MethodCall &call)
{
    const auto &method = call.GetMethod();

    if (method == "create") {
        onCreate(call);
        return;
    }

    if (method == "remove") {
        onRemove(call);
        return;
    }

    unimplemented(call);
}

void EmbedderTexturePlugin::onCreate(const MethodCall &call)
{
    auto cameraId = 0;
    auto width = call.GetArgument<Encodable::Int>("width");
    auto height = call.GetArgument<Encodable::Int>("height");

    auto result = m_camera->Register(cameraId, width, height);

    result["orientation"] = static_cast<int>(PlatformMethods::GetOrientation());

    call.SendSuccessResponse(result);
}

void EmbedderTexturePlugin::onRemove(const MethodCall &call)
{
    auto textureId = call.GetArgument<Encodable::Int>("textureId");

    m_camera->Unregister();

    call.SendSuccessResponse(true);
}

void EmbedderTexturePlugin::unimplemented(const MethodCall &call)
{
    call.SendSuccessResponse(nullptr);
}
