/**
 * SPDX-FileCopyrightText: Copyright 2023 Open Mobile Platform LLC <community@omp.ru>
 * SPDX-License-Identifier: BSD-3-Clause
 */
#ifndef CAMERA_BUFFER_H
#define CAMERA_BUFFER_H

#include <flutter/plugin-interface.h>
#include <streamcamera/streamcamera.h>

#include <QImage>
#include <QtCore>

class Camera : public Aurora::StreamCamera::CameraListener
{
public:
    Camera(TextureRegistrar *plugin);

    void onCameraError(const std::string &errorDescription) override;
    void onCameraFrame(std::shared_ptr<Aurora::StreamCamera::GraphicBuffer> buffer) override;
    void onCameraParameterChanged(Aurora::StreamCamera::CameraParameter,
                                  const std::string &value) override;

    std::map<Encodable, Encodable> Register(int cameraID, int width, int height);
    void Unregister();

private:
    void InitializeCamera(int cameraID);
    Aurora::StreamCamera::CameraCapability StartCapture();
    void StopCapture();

private:
    TextureRegistrar *m_plugin;

    Aurora::StreamCamera::CameraManager *m_manager;
    std::shared_ptr<Aurora::StreamCamera::Camera> m_camera;

    int m_cameraId = -1;
    int64_t m_textureId;

    int m_widthTexture;
    int m_heightTexture;

    TextureVariant *m_buffer;
};

#endif /* CAMERA_BUFFER_H */
