import 'package:embedder_texture/embedder_texture.dart';
import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'embedder_texture_method_channel.dart';

abstract class EmbedderTexturePlatform extends PlatformInterface {
  /// Constructs a LinuxOpenglPlatform.
  EmbedderTexturePlatform() : super(token: _token);

  static final Object _token = Object();

  static EmbedderTexturePlatform _instance = MethodChannelEmbedderTexture();

  /// The default instance of [LinuxOpenglPlatform] to use.
  ///
  /// Defaults to [MethodChannelLinuxOpengl].
  static EmbedderTexturePlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [LinuxOpenglPlatform] when
  /// they register themselves.
  static set instance(EmbedderTexturePlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Stream<OrientationEvent> onChangeOrientation() {
    throw UnimplementedError('onChangeOrientation() has not been implemented.');
  }

  Future<Map<dynamic, dynamic>> create(double width, double height) {
    throw UnimplementedError('create() has not been implemented.');
  }

  Future<bool> remove(int textureId) {
    throw UnimplementedError('remove() has not been implemented.');
  }
}
